@@ -29,14 +29,11 @@ def check_type(argname: str, value: object, expected_type: typing.Any) -> typing
                 typeguard.check_type(value=value, expected_type=expected_type, collection_check_strategy=typeguard.CollectionCheckStrategy.ALL_ITEMS) # type:ignore
 
 import cdk8s._jsii
-import cdk8s_plus_29._jsii
+import cdk8s_plus_30._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@bluedynamics/cdk8s-plone",
-    "0.0.59",
-    __name__[0:-6],
-    "cdk8s-plone@0.0.59.jsii.tgz",
+    "@bluedynamics/cdk8s-plone", "0.1.2", __name__[0:-6], "cdk8s-plone@0.1.2.jsii.tgz"
 )
 
 __all__ = [
